@@ -212,3 +212,26 @@ class TestViewMixins(TestCase):
 
         response = view(request)
         self.assertContains(response, b'foo-post-title')
+
+    def test_any_perm_parameter(self):
+        request = self.factory.get('/')
+        request.user = self.user
+        request.user.add_obj_perm('view_post', self.post)
+        self.assertIs(request.user.has_perm('view_post', self.post), True)
+        self.assertIs(request.user.has_perm('change_post', self.post), False)
+        # success way
+        view = TestView.as_view(
+            any_perm=True,
+            permission_required=['change_post', 'view_post'],
+            object=self.post,
+        )
+        with self.assertRaises(DatabaseRemovedError):
+            view(request)
+        # fail way
+        view = TestView.as_view(
+            any_perm=False,
+            permission_required=['change_post', 'view_post'],
+            object=self.post,
+        )
+        response = view(request)
+        self.assertEqual(response.status_code, 302)
